@@ -7,15 +7,34 @@ package main;
 
 sub usage {
     print STDERR "Usage: slice [options] [file]\n";
-    print STDERR "   where options are\n";
-    print STDERR "   -o [sliceterm:]file[\@chmodopt]  create output file\n";
-    print STDERR "   -x                              verbose/debug mode\n";
-    print STDERR "   -v                              version string\n";
+    print STDERR "\n";
+    print STDERR "Options:\n";
+    print STDERR "  -o, --outputfile=FILESPEC  create output file(s)\n";
+    print STDERR "  -v, --verbose              enable verbose mode\n";
+    print STDERR "  -V, --version              display version string\n";
+    print STDERR "  -h, --help                 display usage page\n";
+    print STDERR "\n";
+    print STDERR "FILESPEC format:\n";
+    print STDERR "\n";
+    print STDERR "  [SLICETERM:]PATH[\@CHMODOPT]\n";
+    print STDERR "\n";
+    print STDERR "  SLICETERM ..... a set-theory term describing the slices\n";
+    print STDERR "  PATH .......... a filesystem path to the outputfile\n";
+    print STDERR "  CHMODOPT ...... permission change options for 'chmod'\n";
+    print STDERR "\n";
     exit(1);
 }
 
 sub hello {
     print STDERR "$Vers::SLICE_Hello\n";
+    print STDERR <<'EOT';
+Copyright (c) 1996-1997 Ralf S. Engelschall, All Rights Reserved.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+EOT
     exit(0);
 }
 
@@ -23,19 +42,25 @@ sub setup {
     my ($CFG) = @_;
 
     #   parse command line options
-    $opt_x = 0;
+    $opt_h = 0;
+    $opt_V = 0;
     $opt_v = 0;
     @opt_o = ();
+    $SIG{'__WARN__'} = sub { 
+        print STDERR "Slice:Error: $_[0]";
+    };
     $Getopt::Long::bundling = 1;
     $Getopt::Long::getopt_compat = 0;
-    if (not Getopt::Long::GetOptions("x|debug",
-                                     "v|version",
+    if (not Getopt::Long::GetOptions("v|verbose",
+                                     "V|version",
+                                     "h|help",
                                      "o|outputfile=s@")) {
-        &usage;
-    }
-    if ($opt_v) {
-        &hello;
+        print STDERR "Try `$0 --help' for more information.\n";
+        exit(0);
     }
+    $SIG{'__WARN__'} = undef;
+    &usage($0) if ($opt_h);
+    &hello() if ($opt_V);
 
     #   process command line arguments and
     #   read input file
@@ -73,7 +98,7 @@ sub setup {
     $CFG->{INPUT}->{SRC}   = $INPUT;  # original source
     $CFG->{INPUT}->{PLAIN} = '';      # source without slice delimiters
     $CFG->{OPT} = {};    
-    $CFG->{OPT}->{X} = $opt_x;        # option -x
+    $CFG->{OPT}->{X} = $opt_v;        # option -v
     $CFG->{OPT}->{O} = [ @opt_o ];    # options -o
     $CFG->{SLICE} = {};
     $CFG->{SLICE}->{SET} = {};       
